var _ = require('underscore');
var util = require('util');
var should = require('should');

var ObjectHelper = require('../object_helper.js');

var objectA = {
    car: {
        carTypes: [
            {val: 'carType1', text: 'carTypeText1', children: [
                {val: 'carType1Child1', text: 'carType1Child1Text', children: [
                    {val: 'carType1Child1Child1', text: 'carType1Child1Child1Text', }
                ],
                }
            ],
            }
        ],
        foo: [
            {active: false, val: 'foo1', text: 'fooText1', children: [
                {val: 'foo1Child1', text: 'foo1Child1Text', children: [
                    {val: 'foo1Child1Child1', text: 'foo1Child1Child1Text', }
                ],
                }
            ],
            }
        ],
        bar: [
            {val: 'bar1', text: 'barText1', children: [
                {val: 'bar1Child1', text: 'bar1Child1Text', },
            ],
            }
        ],
        brands: [
            {val: 'volvo', text: 'VOLVO', },
            {val: 'saab', text: 'SAAB', },
        ],
    },
    regions: [
        {val: '120000', text: 'Skane', },
        {val: '140000', text: 'Ninja land', children: [
            {val: '141200', text: 'Pirate land', },
        ], },
    ],
    prospectTypes: [
        {val: 'company', text: 'Företag', },
        {val: 'private', text: 'Privat', },
    ],
};

describe('ObjectHelper', function() {

    it('Can deep-copy object', function() {
        var cloneA = ObjectHelper.deepCopyObject(objectA);

        cloneA.regions.push({val: '123'});

        objectA.regions.should.be.length(2);
        cloneA.regions.should.be.length(3);
    });

    it('Can transform array values to objects', function() {
        var obj = {
            prospectTypes: ['privatePerson'],
            car: {
                carTypes: ['carType1'],
            },
        };

        var transformedObj = ObjectHelper.transformArrayValuesToObjects(obj);

        transformedObj.should.deepEqual({
            prospectTypes: [{val: 'privatePerson'}],
            car: {
                carTypes: [{val: 'carType1'}],
            },
        });

        obj = {
            prospectTypes: [
                {val: 'privatePerson', text: 'PrivatePerson', },
            ],
        };

        transformedObj = ObjectHelper.transformArrayValuesToObjects(obj);

        transformedObj.should.deepEqual(obj);
    });

});
