/** @flow */
var moment = require('moment');
var AgileHelper = {
    /**
     * Get's the most prioritized event of a deal, relative to NOW.
     * If the event datetime is overdue, the event that's most overdue is returned.
     * Otherwise, the event closest to NOW is returned.
     *
     * @param {Object} deal Deal with events.
     * @returns (Moment object) Event datetime that's closest to NOW or most overdue.
     */
    getPrioritizedEvent : function(deal) {
        var minDate = null;
        var now = moment();
        
        for(var i = 0, len = deal.events.length; i < len; i += 1) {
            //Make sure not falsy deal.
            if(deal.events[i].event_date === null || deal.events[i].event_date === undefined) {
                continue;
            }

            var dueDate = moment(deal.events[i].event_date);
            if(dueDate.isValid() === false) {
                throw 'Invalid due date: ' + dueDate.invalidAt();
            }

            if(minDate === null) {
                minDate = dueDate;
            } else {
                minDate = moment.min(minDate, dueDate);
            }
        }

        return minDate;
    }
};

module.exports = Object.create(AgileHelper);
