var nls = require('nls');

/**
 * CouplingHelper
 * @author David Ajnered
 * @version 1.1.0
 *   1.0.0 - Initial
 *   1.1.0 - Changed code with es6 syntax to es5
 */
var CouplingHelper = {

    /**
     * Get all couplings
     * @return {array}
     */
    getAllCouplings: function() {
        return [
            nls.ball,
            nls.hook,
            nls.shackle,
            nls.other,
            nls.pivot,
            nls.hitch,
            nls.eyelet,
            nls.tap,
            nls.agricultular,
            nls.detachableBall,
            nls.another
        ];
    },

    /**
     * Get coupling name from id.
     * @param {int} id
     * @return {string}
     */
    getById: function(id) {
        id = +id;

        if (id) {
            var couplings = this.getAllCouplings();
            return (couplings[id]) ? couplings[id] : null;
        } else {
            return null;
        }
    },

    /**
     * Get prospect filter
     * @return {array}
     */
    getFilter: function() {
        var couplings = this.getAllCouplings();
        var filters = [];
        couplings.forEach(function(name, index) {
            var filter = {
                val: index + 1,
                text: name
            };
            filters.push(filter);
        });

        return filters;
    }
};

module.exports = Object.create(CouplingHelper);
