var nls = require('nls'),
    _ = require('underscore');

var FuelHelper = {
    getReadableFuel : function(fuel) {
        if(fuel === null || fuel === undefined) return nls.noInfo;
        //No nls you say? I'm lasy you say? Well sue me!
        var fuels = this.getFuels();
        return fuels[fuel] || nls.noInfo;
    },
    getFuels : function() {
        return {
            1 : "Bensin",
            2 : "Diesel",
            3 : "El",
            4 : "Fotogen",
            6 : "Gengas",
            7 : "Etanol",
            9 : "Motorgas",
            16 : "Metangas",
            17 : "Vätgas",
            18: "Annat",
            19: "Biodiesel"
        };
    },
    _convertToUnit : function(unit, del) {
        if(unit === 0 || unit === undefined) {
            return null; //If val 0, dont show anything
        }

        unit = unit.toString(); //Convert to string, so we can slice it up.
        return unit.slice(0,-1) + ',' + unit.slice(-1) + ' ' + del;
    },
    /**
    * Converts CO2 units from TS to readable format, in g/km.
    */
    getReadableCO2 : function(fuelType,co2) {
        if(fuelType > 0 && co2 === 0) {
            return null;
        }
        return this._convertToUnit(co2,nls.gperkm);
    },
    /**
    * Converts CO2 units from TS to readable format, in g/km.
    */
    getReadableFuelMetric : function(fuelType,val) {
        if(fuelType > 0 && val === 0) {
            return null;
        }
        //Metrics per fuel. 
        var units = { 
            1 : nls.literperkm,
            2 : nls.literperkm,
            3 : "", //Electric has no fuelusage, no shown metric.
            4 : "", //No defined
            6 : "", //No defined
            7 : "", //No defined
            9 : nls.cubicmperkm,
            16 : nls.cubicmperkm,
            17 : nls.cubicmperkm,
            18: "", //No defined
            19: "" //None defined
        };
        return this._convertToUnit(val,units[fuelType]);
    }
};


module.exports = Object.create(FuelHelper);
