var nls = require('nls');
var _ = require('underscore');

/**
 * Object for handling formatting of gender
 *
 * @author Viktor Silfverstrom <viktor@silfverstrom.com>
 * @version 1.1.0
 *   1.0.0 - Initial
 *   1.1.0 - Changed code from es6 syntax to es5
 * @since 2.0.0 - Hawkeye
 */
var GenderHelper = {
    /**
     * Formats a gender by it's value
     *
     * @name getGender
     * @function
     * @author Viktor Silfverstrom <viktor@silfverstrom.com>
     * @version 1.0.0
     * @since 1.0.0
     * @access public
     * @param {string} genderKey The value of the gender, e.g M, K, O. Can also be already formatted value, then it will return that.
     * @return {string|null} Returns male, female or null
     */
    getGender: function(genderKey) {
        if (!genderKey) {
            return null;
        }

        var genderKey = genderKey.toUpperCase();
        var genders = this._getAllGenders();
        return (_.contains(['M', 'K', 'E'], genderKey)) ? genders[genderKey] : null;
    },

    /**
     * Get gender or company
     * @param {string} genderKey The value of the gender, e.g M, K, O. Can also be already formatted value, then it will return that.
     * @return {string}
     */
    getGenderOrCompany: function(genderKey) {
        var genders = this._getAllGenders();
        if (genderKey) {
            genderKey = genderKey.toUpperCase();
            return genders[genderKey] || genderKey;
        } else {
            return nls.noInfo;
        }
    },

    /**
     * Returns all available gender formatting.
     *
     * @name _getAllGenders
     * @function
     * @author Viktor Silfverstrom <viktor@silfverstrom.com>
     * @version 1.0.0
     * @since 1.0.0
     * @access private
     * @return {Object}
     */
    _getAllGenders: function() {
        return {
            'K': nls.female,
            'M': nls.male,
            'O': nls.company,
            'E': nls.noGender,
        }
    }
};

module.exports = Object.create(GenderHelper);
