var nls = require('nls'); //Relative needed since shared doesn't have it's own node_modules.

/**
 * Object for handling all maturity info
 *
 * @author Viktor Silfverstrom <viktor@silfverstrom.com>
 * @version 1.0.0
 * @since 2.0.0 - Hawkeye
 */
var MaturityHelper = {
    /**
     * Formats a maturity by it's value
     *
     * @name getMaturity
     * @function
     * @author Viktor Silfverstrom <viktor@silfverstrom.com>
     * @version 1.0.0
     * @since 1.0.0
     * @access public
     * @param {number|string} maturity The value of the maturity i.e -1 to 4
     * @return {string} The formatted maturity value
     */
    getMaturity : function(maturity) {
        var arr = this._getAllMaturity();
        return arr[maturity] || nls.noInfo;
    },
    /**
     * Returns all current maturity values
     *
     * @name _getAllMaturity
     * @function
     * @author Viktor Silfverstrom <viktor@silfverstrom.com>
     * @version 1.0.0
     * @since 1.0.0
     * @access private
     * @return {Object} 
     */
    _getAllMaturity : function() {
        return {
            '-1' : nls.advertisingBlocked,
            0  : nls.iceCold,
            1  : nls.cold,
            2  : nls.lukewarm,
            3  : nls.warm,
            4  : nls.burning
        };
    }
};

module.exports = Object.create(MaturityHelper);
