var _ = require('underscore');
var R = require('ramda');
var util = require('util');

/**
 * For working with JavaScript objects.
 *
 * @version 1.2.0
 *   1.0.0 Initial
 *   1.1.0 Added transformArrayValuesToObjects function
 *   1.2.0 Changed code from es6 syntax to es5
 */

var ObjectHelper = {
    deepCopyObject: function(obj) {
        try {
            return JSON.parse(JSON.stringify(obj)); //Create a deep copy
        } catch (err) {
            console.error('Invalid deep copy object', obj, err);
        }
    },

    transformArrayValuesToObjects: function(obj) {

        var loop = function loopF(a, insideArr) {
            if (typeof insideArr === 'undefined') insideArr = false;

            if (_.isArray(a)) {
                return _(a).map(function(x) {
                    return loopF(x, true);
                });
            } else if (_.isObject(a)) {
                return _(a).mapObject(function(x) {
                    return loopF(x, false);
                });
            } else if (insideArr) {
                return {val: a};
            }

            return a;
        };

        return loop(this.deepCopyObject(obj));
    },

    inspectObject: function(str, obj, settings) {
        var _settings = {
            depth: (settings && settings.depth) || null,
            colors: (settings && settings.colors) || true
        };
        console.log(str, util.inspect(obj, _settings));
    },
};

module.exports = Object.create(ObjectHelper);
