var _ = require('underscore');
var nls = require('nls/main-sv');
/** Släpvagnar (inklusive semi-trailer)
O1	Släpvagn med totalvikt under 750 kg.
O2	Släpvagn med totalvikt över 750 kg men ej över 3,5 ton.
O3	Släpvagn med totalvikt över 3,5 ton men ej över 10 ton.
O4	Släpvagn med totalvikt över 10 ton.
https://sv.wikipedia.org/wiki/Fordonskategori
*/
var zero = {
    val: 'O1',
    text: 'segment under utveckling!'
};
var first = {
    val: 'O1',
    text: '<750kg'
};

var second = {
    val: 'O2',
    text: '>750kg,<3,5ton'
};

var third = {
    val: 'O3',
    text: '>3,5ton,<10ton '
};

var fourth = {
    val: 'O4',
    text: '>10ton'
};
/**
 * Get SV segments
 */
function getSVSegments() {
    var distlist = {
        val: 'SV',
        text: 'Släpvagnar',
        // children: [zero, first, second, third, fourth],
        children: [], // Need children property for preview to work as other car types.
    };

    return distlist;
};

exports.getSVSegments = getSVSegments;

/**
 * Returns a list of all segments that should be searched, given a segment.
 * Thus, using this will return getHierarchy + recursive children on last element.
 */
function getMatchingValues(val) {
    var hier = getHierarchy(val);
    var last = _(hier).last();

    function loop(row, list) {
        if (row.children) {
            for (var x = 0; x < row.children.length; x++) {
                var child = row.children[x];
                list.push(child.val);
                loop(child, list);
            }
        }
    };

    var nestedChilds = [];
    loop(last, nestedChilds);
    return _(hier).map(function (val) {
        return val.val;
    }).concat(nestedChilds);
};

exports.getMatchingValues = getMatchingValues;

/**
 * Returns ordered list of hierarchy.
 */
function getHierarchy(val) {
    function loop(row, list) {
        if (!list) {
            list = [];
        }

        if (val && row.val.toLowerCase() === val.toLowerCase()) {
            list.push(row);
            return true;
        } else if (row.children) {
            for (var x = 0; x < row.children.length; x++) {
                var child = row.children[x];
                var gotIt = loop(child, list);

                if (gotIt) {
                    list.push(row);
                    return true;
                }
            }
        } else {
            return false;
        }
    }

    var li = [];
    loop(getSVSegments(), li);
    return li.reverse();
};

exports.getHierarchy = getHierarchy;
