var _ = require('underscore');
var nls = require('nls/main-sv');

var dist = {
    val: 'distribution',
    text: 'Distribution',
    children: [
        {
            val: 'distributionAvfallshantering',
            text: 'Avfallshantering',
            children: [
                {
                    val: 'distributionAvfallshanteringSopbilar',
                    text: 'Sopbilar',
                },
                {
                    val: 'distributionAvfallshanteringSlambilar',
                    text: 'Slambilar',
                },
            ],
        },
        {
            val: 'distributionSkapbilar',
            text: 'Skåpbilar',
            children: [
                {
                    val: 'distributionSkapbilarTransportskap',
                    text: 'Transportskåp',
                },
                {
                    val: 'distributionSkapbilarTempereratGods',
                    text: 'Tempererat gods',
                },
                {
                    val: 'distributionSkapbilarOvrigt',
                    text: 'Övrigt',
                },
            ],
        },
        {
            val: 'distributionOvrigt',
            text: 'Övrigt',
            children: [
                {
                    val: 'distributionOvrigtFordonstransport',
                    text: 'Fordonstransport',
                },
                {
                    val: 'distributionOvrigtDjurtransport',
                    text: 'Djurtransport',
                },
                {
                    val: 'distributionOvrigtBrandfordon',
                    text: 'Brandfordon',
                },
                {
                    val: 'distributionOvrigtOvrigt',
                    text: 'Övrigt',
                },
            ],
        },
        {
            val: 'distributionContainer',
            text: 'Container',
        },
    ],
};

var entreprenad = {
    val: 'entreprenad',
    text: 'Entreprenad',
    children: [
        {
            val: 'entreprenadLastvaxlare',
            text: 'Lastväxlare',
            children: [
                {
                    val: 'entreprenadLastvaxlareLiftdumper',
                    text: 'Liftdumper',
                },
                {
                    val: 'entreprenadLastvaxlareLastvaxlare',
                    text: 'Lastväxlare',
                },
            ],
        },
        {
            val: 'entreprenadFlakbilar',
            text: 'Flakbil',
            children: [
                {
                    val: 'entreprenadFlakbilarLammar',
                    text: 'Lämmar',
                },
                {
                    val: 'entreprenadFlakbilarSchaktbilar',
                    text: 'Schaktbilar',
                },
                {
                    val: 'entreprenadFlakbilarOvrigt',
                    text: 'Övrigt',
                },
            ],
        },
        {
            val: 'entreprenadTimmerbilar',
            text: 'Timmerbil',
        },
        {
            val: 'entreprenadOvrigt',
            text: 'Övrigt',
            children: [
                {
                    val: 'entreprenadOvrigtSnabblas',
                    text: 'Snabblås',
                  },
                {
                    val: 'entreprenadOvrigtBetongbilar',
                    text: 'Betongbilar',
                },
            ],
        },
    ],
};

var fjarr = {
    val: 'fjarrtrafik',
    text: 'Fjärrtrafik',
    children: [
        {
            val: 'fjarrtrafikDragbilar',
            text: 'Dragbilar',
        },
        {
            val: 'fjarrtrafikContainer',
            text: 'Container',
        },
        {
            val: 'fjarrtrafikSkapbilar',
            text: 'Skåpbil',
            children: [
                {
                    val: 'fjarrtrafikSkapbilarTransportskap',
                    text: 'Transportskåp',
                },
                {
                    val: 'fjarrtrafikSkapbilarTempereratGods',
                    text: 'Tempererat gods',
                },
                {
                    val: 'fjarrtrafikSkapbilarSkapbilarOvrigt',
                    text: 'Övrigt',
                },
            ],
        },
        {
            val: 'fjarrtrafikOvrigt',
            text: 'Övrigt',
            children: [
                {
                    val: 'fjarrtrafikOvrigtFordonstransport',
                    text: 'Fordonstransport',
                },
                {
                    val: 'fjarrtrafikOvrigtDjurtransport',
                    text: 'Djurtransport',
                },
                {
                    val: 'fjarrtrafikOvrigtTankbilar',
                    text: 'Tankbilar',
                },
                {
                    val: 'fjarrtrafikOvrigtBulkbilar',
                    text: 'Bulkbilar',
                },
                {
                    val: 'fjarrtrafikOvrigtOvrigt',
                    text: 'Övrigt',
                },
            ],
        },
    ],
};

var fjarrdistance = {
    val: 'fjarrtrafikDistributionEntreprenad',
    text: 'Fjärrtrafik/distribution/entreprenad',
};

/**
 * Get TLB segments
 */
function getTLBSegments() {
    var distlist = {
        val: 'TLB',
        text: nls.TLB,
        children: [dist, entreprenad, fjarr, fjarrdistance],
    };

    return distlist;
};

exports.getTLBSegments = getTLBSegments;

/**
 * Returns a list of all segments that should be searched, given a segment.
 * Thus, using this will return getHierarchy + recursive children on last element.
 */
function getMatchingValues(val) {
    var hier = getHierarchy(val);
    var last = _(hier).last();

    function loop(row, list) {
        if (row.children) {
            for (var x = 0; x < row.children.length; x++) {
                var child = row.children[x];
                list.push(child.val);
                loop(child, list);
            }
        }
    };

    var nestedChilds = [];
    loop(last, nestedChilds);
    return _(hier).map(function (val) {
        return val.val;
    }).concat(nestedChilds);
};

exports.getMatchingValues = getMatchingValues;

/**
 * Returns ordered list of hierarchy.
 */
function getHierarchy(val) {
    function loop(row, list) {
        if (!list) {
            list = [];
        }

        if (val && row.val.toLowerCase() === val.toLowerCase()) {
            list.push(row);
            return true;
        } else if (row.children) {
            for (var x = 0; x < row.children.length; x++) {
                var child = row.children[x];
                var gotIt = loop(child, list);

                if (gotIt) {
                    list.push(row);
                    return true;
                }
            }
        } else {
            return false;
        }
    }

    var li = [];
    loop(getTLBSegments(), li);
    return li.reverse();
};

exports.getHierarchy = getHierarchy;
